==> sword-1.1.0.tgz: sword/include/swdisprtf.h <==
//---------------------------------------------------------------------------
#ifndef SWDispRTFH
#define SWDispRTFH
//---------------------------------------------------------------------------
#include <vcl\SysUtils.hpp>
#include <vcl\Controls.hpp>
#include <vcl\Classes.hpp>
#include <vcl\Forms.hpp>
#include <vcl\ComCtrls.hpp>
#include <vcl\StdCtrls.hpp>
#include <swtext.h>
//---------------------------------------------------------------------------

#define	defRTFHeader          "{\\rtf1\\ansi{\\fonttbl{\\f0\\froman\\fcharset0\\fprq2 Times New Roman;}{\\f1\\froman\\fcharset0\\fprq2 Times New Roman;}{\\f2\\froman\\fcharset2\\fprq2 Symbol;}{\\f3\\froman\\fcharset2\\fprq2 Symbol;}}{\\colortbl;\\red0\\green0\\blue255;\\red0\\green200\\blue50;\\red0\\green0\\blue255;\\red0\\green200\\blue50;\\red0\\green0\\blue255;\\red255\\green0\\blue0;}"
#define	defRTFTrailer         "{\\fs24 \\par }}"

#define	defRTFChapterMarkPre  "\\pard \\qc\\nowidctlpar{\\f1\\fs30\\b Chapter "
#define	defRTFChapterMarkPost "\\par\\fs10\\par}"

#define	defRTFVerseMarkPre    "{\\fs20\\cf1\\super "
#define	defRTFVerseMarkPost   "}"

#define	defRTFVersePre        "{\\fs24"
#define	defRTFVersePost       " }"


class SWDispRTF : public TRichEdit {
protected:

		System::AnsiString FRTFHeader;
		System::AnsiString FRTFTrailer;
		System::AnsiString FRTFChapterMarkPre;
		System::AnsiString FRTFChapterMarkPost;
		System::AnsiString FRTFVerseMarkPre;
		System::AnsiString FRTFVerseMarkPost;
		System::AnsiString FRTFVersePre;
		System::AnsiString FRTFVersePost;
		CHARRANGE FCharRange;
		
		int __fastcall GetMySelStart();
		void __fastcall SetMySelStart(int iselstart);
protected:
		TMemoryStream *RTFStream;
		
		virtual void __fastcall Loaded(void);
public:
	__fastcall SWDispRTF(TComponent* Owner);
	__fastcall ~SWDispRTF();

	virtual char Display(SWModule &imodule);
__published:
		__property System::AnsiString RTFHeader          = {read=FRTFHeader,           write=FRTFHeader};
		__property System::AnsiString RTFChapterMarkPre  = {read=FRTFChapterMarkPre,   write=FRTFChapterMarkPre};
		__property System::AnsiString RTFChapterMarkPost = {read=FRTFChapterMarkPost,  write=FRTFChapterMarkPost};
		__property System::AnsiString RTFVerseMarkPre    = {read=FRTFVerseMarkPre,     write=FRTFVerseMarkPre};
		__property System::AnsiString RTFVerseMarkPost   = {read=FRTFVerseMarkPost,    write=FRTFVerseMarkPost};
		__property System::AnsiString RTFVersePre        = {read=FRTFVersePre,         write=FRTFVersePre};
		__property System::AnsiString RTFVersePost       = {read=FRTFVersePost,        write=FRTFVersePost};
		__property System::AnsiString RTFTrailer         = {read=FRTFTrailer,          write=FRTFTrailer};
};
//---------------------------------------------------------------------------
#endif

==> sword-1.1.1.tgz: sword/include/swdisprtf.h <==
//---------------------------------------------------------------------------
#ifndef SWDispRTFH
#define SWDispRTFH
//---------------------------------------------------------------------------
#include <vcl\SysUtils.hpp>
#include <vcl\Controls.hpp>
#include <vcl\Classes.hpp>
#include <vcl\Forms.hpp>
#include <vcl\ComCtrls.hpp>
#include <vcl\StdCtrls.hpp>
#include <swtext.h>
//---------------------------------------------------------------------------

#define	defRTFHeader          "{\\rtf1\\ansi{\\fonttbl{\\f0\\froman\\fcharset0\\fprq2 Times New Roman;}{\\f1\\froman\\fcharset0\\fprq2 Times New Roman;}{\\f2\\froman\\fcharset2\\fprq2 Symbol;}{\\f3\\froman\\fcharset2\\fprq2 Symbol;}}{\\colortbl;\\red0\\green0\\blue255;\\red0\\green200\\blue50;\\red0\\green0\\blue255;\\red0\\green200\\blue50;\\red0\\green0\\blue255;\\red255\\green0\\blue0;} {\\fs8\\cf1\\par\\pard} "
#define	defRTFTrailer         "{\\fs24 \\par }}"

#define	defRTFChapterMarkPre  "\\pard \\qc\\nowidctlpar{\\f1\\fs30\\b Chapter "
#define	defRTFChapterMarkPost "\\par\\fs10\\par}"

#define	defRTFVerseMarkPre    "{\\fs20\\cf1\\super "
#define	defRTFVerseMarkPost   "}"

#define	defRTFVersePre        "{\\fs24"
#define	defRTFVersePost       " }"


class SWDispRTF : public TRichEdit {
protected:

		System::AnsiString FRTFHeader;
		System::AnsiString FRTFTrailer;
		System::AnsiString FRTFChapterMarkPre;
		System::AnsiString FRTFChapterMarkPost;
		System::AnsiString FRTFVerseMarkPre;
		System::AnsiString FRTFVerseMarkPost;
		System::AnsiString FRTFVersePre;
		System::AnsiString FRTFVersePost;
		CHARRANGE FCharRange;
		
		int __fastcall GetMySelStart();
		void __fastcall SetMySelStart(int iselstart);
protected:
		TMemoryStream *RTFStream;
		
		virtual void __fastcall Loaded(void);
public:
	__fastcall SWDispRTF(TComponent* Owner);
	__fastcall ~SWDispRTF();

	virtual char Display(SWModule &imodule);
__published:
		__property System::AnsiString RTFHeader          = {read=FRTFHeader,           write=FRTFHeader};
		__property System::AnsiString RTFChapterMarkPre  = {read=FRTFChapterMarkPre,   write=FRTFChapterMarkPre};
		__property System::AnsiString RTFChapterMarkPost = {read=FRTFChapterMarkPost,  write=FRTFChapterMarkPost};
		__property System::AnsiString RTFVerseMarkPre    = {read=FRTFVerseMarkPre,     write=FRTFVerseMarkPre};
		__property System::AnsiString RTFVerseMarkPost   = {read=FRTFVerseMarkPost,    write=FRTFVerseMarkPost};
		__property System::AnsiString RTFVersePre        = {read=FRTFVersePre,         write=FRTFVersePre};
		__property System::AnsiString RTFVersePost       = {read=FRTFVersePost,        write=FRTFVersePost};
		__property System::AnsiString RTFTrailer         = {read=FRTFTrailer,          write=FRTFTrailer};
};
//---------------------------------------------------------------------------
#endif
